@@ -60,7 +60,7 @@ This method simply eases the raising of some specific errors.
         raise Exception('BUG !')
 
     raise LaTeXUseError(
-        "The following {0} {1}.\n\t''{2}''".format(kind, action, path)
+        "The following {0} {1}.\n\t<< {2} >>".format(kind, action, path)
     )
 
 
@@ -133,7 +133,7 @@ info::
     """
     if not mode in CHAR_TO_ESCAPE:
         raise LaTeXUseError(
-            "Unknown mode : ''{0}''.".format(mode)
+            "Unknown mode : << {0} >>.".format(mode)
         )
 
     charToLatexify = CHAR_TO_LATEXIFY[mode].items()
@@ -173,7 +173,7 @@ info::
 # -- COMPILING -- #
 # --------------- #
 
-class Build(object):
+class Build:
     """
 -----------------
 Small description
@@ -588,7 +588,7 @@ The key ``'localDir'`` contains the path to use to install special packages.
 # Unknown method...
     else:
         raise LaTeXUseError(
-            "The OS ''{0}'' is not supported. ".format(osName)
+            "The OS << {0} >> is not supported. ".format(osName)
         )
 
 # The job has been done...
@@ -684,7 +684,7 @@ importation of the module ``latexUse``.
     print(
         '',
         'The following local directory for MiKTeX has been created.',
-        '\t"{0}"'.format(mikeTexLocalDirectory()),
+        '\t<< {0} >>'.format(mikeTexLocalDirectory()),
         sep = "\n"
     )
 
@@ -769,7 +769,7 @@ This function uses the following variables.
         message = "No local directroy for special packages has been found."
 
         if aboutLatex['latexName'] == "miktex":
-            message = message + "You can use the function ''makeMiktexLocalDir''."
+            message += "You can use the function << makeMiktexLocalDir >>."
 
         raise LaTeXUseError(message)
 
@@ -820,7 +820,7 @@ This function uses the following variables.
 #    1) Deletion of a local package named ``name``
         if clean and os_use.isDir(localLatexDir):
             print(
-                decoTab + 'Deletion of the old "{0}" '.format(name) \
+                decoTab + 'Deletion of the old << {0} >> '.format(name) \
                 + 'package in the local LaTeX directory.'
             )
 
@@ -828,14 +828,14 @@ This function uses the following variables.
 
 #    2) Creation of the new local package named ``name``
         print(
-            decoTab + 'Creation of the new "{0}" '.format(name) \
+            decoTab + 'Creation of the new << {0} >> '.format(name) \
             + 'package in the local LaTeX directory.'
         )
 
 #    3) Creation of the new directories with their contents
         for oneNewDir in sorted(dirAndTheirFiles.keys()):
             print(
-                decoTabPlus + 'Adding new directory --> "{0}" '.format(
+                decoTabPlus + 'Adding new directory --> << {0} >> '.format(
                     oneNewDir
                 )
             )
@@ -851,7 +851,7 @@ This function uses the following variables.
                     )
 
                 print(
-                    decoTabMore + 'Adding new file  --> "{0}" '.format(
+                    decoTabMore + 'Adding new file  --> << {0} >> '.format(
                         os_use.fileName(oneFile) \
                         + "." \
                         + os_use.ext(oneFile)
@@ -875,5 +875,5 @@ This function uses the following variables.
     else:
         raise LaTeXUseError(
             'The installation of local packages is not yet supported '
-            'with the OS "{0}".'.format(aboutLatex['osName'])
+            'with the OS << {0} >>.'.format(aboutLatex['osName'])
         )
