@@ -3,7 +3,7 @@
 """
 Directory : mistool
 Name      : osUse
-Version   : 2013.04
+Version   : 2013.06
 Author    : Christophe BAL
 Mail      : projetmbc@gmail.com
 
@@ -537,6 +537,13 @@ Small description
 This small function is used by ``nextFile`` so as to produce two dictionaries
 ``extToKeep`` and ``extToDiscard`` from the variable ``ext``.
     """
+    if extVar == None:
+        extVar = {'keep': "..."}
+
+    elif isinstance(extVar, str) \
+    or isinstance(extVar, list):
+        extVar = {'keep': extVar}
+
     extToKeep = extVar.get('keep', [])
 
     if isinstance(extToKeep, str):
@@ -599,7 +606,7 @@ python::
 
     for onePath in os_use.nextFile(
         main  = "/Users/mistool",
-        ext   = {'keep': "py"},
+        ext   = "py",
         depth = -1
     ):
         print(onePath)
@@ -617,6 +624,35 @@ terminal::
     /Users/mistool/debug/debug_latex_use/latexTestBuilder.py
 
 
+You can also have files with different extensions like in the following code.
+
+python::
+    from mistool import os_use
+
+    for onePath in os_use.nextFile(
+        main  = "/Users/mistool",
+        ext   = ["tex", "pdf"]
+        depth = -1
+    ):
+        print(onePath)
+
+
+If we launch the preceding code in a terminal, then we obtain the following
+outputs.
+
+terminal::
+    /Users/mistool/change_log/2012/07.pdf
+    /Users/mistool/change_log/2012/08.pdf
+    /Users/mistool/change_log/2012/09.pdf
+    /Users/mistool/debug/debug_latex_use/latexTest.pdf
+    /Users/mistool/debug/debug_latex_use/latexTest.tex
+
+
+info::
+    You can also exclude extensions and use some other tuning. See the
+    presentation of the arguments.
+
+
 -------------
 The arguments
 -------------
@@ -625,25 +661,34 @@ This function uses the following variables.
 
     1) ``main`` is simply the path of the main directory to analyse.
 
-    2) ``ext`` is a dictionary of the following kind which is used to keep or to
-    discard some kinds of files.
+    2) ``ext`` gives informations about the extensions of the files wanted. It
+    can be one of the following kinds.
 
-    python::
-        {
-            'keep'   : list of the extensions of files to look for,
-            'discard': list of the extensions of files to discard
-        }
+        i) ``ext`` can be simply a string giving only one extension to keep.
 
-    If ``ext`` is an empty dictionary, or if the two lists are empty ones then
-    the function will send every kind of files.
+        ii) ``ext`` can be a list of strings giving the list of extensions to
+        keep.
 
-    One last thing, if you only need to consider one extension, you can just
-    give it without using one single value list.
+        iii) ``ext`` can be a dictionary of the following kind which is used to
+        keep or to discard some kinds of files.
+
+        python::
+            {
+                'keep'   : the extensions of files to look for,
+                'discard': the extensions of files to discard
+            }
+
+
+        The values giving the extensions can be either a single string, or a list of strings.
+
+    By default, ``ext`` is an empty dictionary. This asks to send every kind of
+    files.
 
     3) ``depth`` is the maximal depth for the research. The very special value
-    ``(-1)`` indicates that there is no maximum. The default value is ``0``
-    which asks to only look for in the direct content of the main directory to
-    analyse.
+    ``(-1)`` indicates that there is no maximum.
+
+    The default value is ``0`` which asks to only look for in the direct content
+    of the main directory to analyse.
 
     4) Let see with one example how to define the dictionary value of the
     variable ``sub``. We assume that the main directory path::``source_dev`` has
