@@ -6,7 +6,7 @@
 """
 Directory : mistool
 Name      : regexUse
-Version   : 2013.04
+Version   : 2013.05
 Author    : Christophe BAL
 Mail      : projetmbc@gmail.com
 
@@ -31,6 +31,26 @@ Base class for errors in the ``regex_use`` module of the package ``mistool``.
     pass
 
 
+# ----------- #
+# -- WORDS -- #
+# ----------- #
+
+__FR_ACCENTUED_LETTERS = "âàéèêëîïôùüç"
+
+PATTERN_GROUP_WORD = {
+# Natural language
+    'en': re.compile("([a-zA-Z]+)"),
+    'fr': re.compile(
+        "([a-z{0}A-Z{1}]+)".format(
+            __FR_ACCENTUED_LETTERS,
+            __FR_ACCENTUED_LETTERS.upper()
+        )
+    ),
+# Coding
+    'var': re.compile("([a-zA-Z][\d_a-zA-Z]*)"),
+}
+
+
 # ----------------------------- #
 # -- LEGAL NAME FOR VARIABLE -- #
 # ----------------------------- #
@@ -262,7 +282,6 @@ using ``sep`` as decimal separator. By default, ``sep = "."``.
         tests = (isInteger, isNatural)
     )
 
-
 def isFloat(
     text,
     sep  = ".",
