@@ -3,7 +3,7 @@
 """
 Directory : mistool
 Name      : stringUse
-Version   : 2013.05
+Version   : 2013.06
 Author    : Christophe BAL
 Mail      : projetmbc@gmail.com
 
@@ -140,7 +140,7 @@ or use your own grouping pattern.
     letters and the special letters "â", "à", "é", "è", "ê", "ë", "î", "ï", "ô",
     "ù", "ü", and "ç".
 
-    2) ``string_use.PATTERN_GROUP_WORD["var"]`` is for words only starting with
+    3) ``string_use.PATTERN_GROUP_WORD["var"]`` is for words only starting with
     one ¨ascii letter followed eventually by other ¨ascii letters, digits and
     underscores.
 
@@ -223,6 +223,8 @@ Small description
 -----------------
 
 This method verifies that there is no cyclic replacements.
+
+Indeed all the job is done by the hidden method ``self.__viciousCircles``.
         """
 # Building the crossing replacements.
         self.__oldWords = list(self.replacement.keys())
@@ -240,13 +242,6 @@ This method verifies that there is no cyclic replacements.
         visitedWord = [],
         nextWord    = None
     ):
-        """
------------------
-Small description
------------------
-
-This method does all the major job for ``self.__noCycle``.
-        """
         if nextWord == None:
             nextWord = self.__oldWords
 
@@ -286,6 +281,8 @@ Small description
 
 This method builds ``self.directReplacement`` the direct replacements
 dictionary.
+
+Indeed all the job is done by the hidden method ``self.__replace``.
         """
         self.directReplacement = {}
 
@@ -296,13 +293,6 @@ dictionary.
         self,
         text
     ):
-        """
------------------
-Small description
------------------
-
-This method does all the major job for ``self.__replaceInReplacement``.
-        """
         if not text:
             return text
 
@@ -346,6 +336,81 @@ function ``replace`` with the attribut ``self.directReplacement``).
         )
 
 
+# ------------------------------------- #
+# -- ASCII TRANSLATION OF AN UTF TEXT-- #
+# ------------------------------------- #
+
+# --- START-ASCII ---#
+
+# The following dictionary was automatically built by one Python script.
+
+REPLACEMENT_ASCII = {
+    '¡': '', '¿': '', 'œ': 'oe', 'à': 'a', 'â': 'a', 'ä': 'a', 'ç': 'c',
+    'é': 'e', 'è': 'e', 'ë': 'e', 'ê': 'e', 'ì': 'i', 'ï': 'i', 'î': 'i',
+    'ñ': 'n', 'ò': 'o', 'ô': 'o', 'ö': 'o', 'ù': 'u', 'û': 'u', 'ü': 'u',
+    'ÿ': 'y'
+}
+
+# --- END-ASCII ---#
+
+def ascii(text):
+    """
+-----------------
+Small description
+-----------------
+
+The aim of this function is to give an ¨ascii translation of a text. The typical use is for avoiding strange names of files. For example, the following lines of code launched in a terminal will display the text ``Viva Espana!``.
+
+python::
+    from mistool import string_use
+
+    print(
+        string_use.ascii("¡Viva España!")
+    )
+
+You can change the constant ``REPLACEMENT_ASCII`` like in the following lines so as to simply obtain ``Viva Espana`` rather than ``Viva Espana!``.
+
+python::
+    from mistool import string_use
+
+    string_use.REPLACEMENT_ASCII['!'] = ""
+
+    print(
+        string_use.ascii("¡Viva España!")
+    )
+
+
+It's easy to improve the special characters managed by default.
+
+    1) The first method can be used for very special tunings like in the
+    preceding code : just add keys with their ¨ascii value to the dictionary
+    ``string_use.REPLACEMENT_ASCII``.
+
+    2) If you think that your tuning is general enough, just send to the author
+    of this module a text file containing the special characters with their
+    ¨ascii translation of the following kind (don't use ``code::``).
+
+    code::
+        a::
+            à ä â
+
+        empty::
+            ¡ ¿
+
+
+    This code uses the ¨peuf specifications of the package ¨orpyste. Here we
+    indicate two things.
+
+        1) The characters ``à``, ``ä`` and ``â`` must be translated to ``a``.
+
+        2) The characters ``¡`` and ``¿`` must be removed.
+    """
+    return replace(
+        text        = text,
+        replacement = REPLACEMENT_ASCII
+    )
+
+
 # ----------------- #
 # -- LOOKING FOR -- #
 # ----------------- #
@@ -1986,8 +2051,8 @@ The arguments
 This method uses one variable ``text`` which is the text of the actual step.
         """
         self.print(
-            self.deco.format(self.nb),
-            text
+            text = text,
+            deco = self.deco.format(self.nb)
         )
 
         self.nb += 1
